$wnd.rstudio.runAsyncCallback3("function y7h(a){this.a=a}\nfunction A7h(a){this.a=a}\nfunction J7h(a){this.a=a}\nfunction ple(a,b){var c;for(c=0;c<a.p.a.length;c++){if(ybd(a.p,c).HL==b){Nme(a.s,ICd(c));break}}}\nfunction x7h(a,b){this.c=a;this.b=SSh(a.c,Wsn,Xsn,bUm).pE();this.a=SSh(a.c,Ysn,Zsn,$sn).pE();Yh(b,new y7h(this),GA?GA:(GA=new _x))}\nfunction v7h(a){var b;b=w7h(a,'weaving Rnw files',a.b,SSh(a.c.c,Wsn,Xsn,bUm));b||w7h(a,'LaTeX typesetting',a.a,SSh(a.c.c,Ysn,Zsn,$sn))}\nfunction t7h(a,b,c){var d;d=c2h(a.b.a);ule(d,qVh(Yig((p7e(),o7e).a)));!!b&&ple(d,b);Ale(d,c);rde(d,true);new x7h(a,d);(edf()||!!$wnd.remoteDesktop)&&idf()}\nfunction F7h(a){try{if(a.c<0)return;!a.a.a&&(a.a.a=dei(a.a.b.a));switch(a.c){case 1:t7h(a.a.a,null,true);break;case 2:t7h(a.a.a,a.b[0],pBd(a.b[1]));}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nfunction w7h(a,b,c,d){if(aH(c)!==aH(d.pE())&&aH(d.eq())!==aH(d.pE())){hVd(2,'Project Option Unchanged','You changed the global option for '+b+bSm+d.pE()+', however the current project is '+'still configured to use '+d.eq()+'.\\n\\n'+'Do you want to edit the options for the current '+'project as well?',new A7h(a),true);return true}else{return false}}\nxVc(2738,1,{},x7h);var $Mb=JBd(2738);xVc(2739,1,yQm,y7h);_.fn=function z7h(a){v7h(this.a)};var YMb=JBd(2739);xVc(2740,1,$Sm,A7h);_.zm=function B7h(){S$d(this.a.c.a.Ug)};var ZMb=JBd(2740);xVc(616,1,rgn);_.xm=function I7h(){F7h((new J7h(this)).a)};xVc(2792,1,ASm,J7h);_.zm=function K7h(){F7h(this.a)};var _Mb=JBd(2792);AJm(El)(3);\n//# sourceURL=rstudio-3.js\n")
