$wnd.rstudio.runAsyncCallback9("function nbj(a){this.a=a}\nfunction faj(a){a.G.sE();xIe(a.i.n)}\nfunction daj(a){Y9h(a.i);otf(a.a,'Load History','loadhistory')}\nfunction eaj(a){Y9h(a.i);ttf(a.a,'Save History As','.Rhistory',false,'savehistory')}\nfunction jbj(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=Sbj(a.a.b.a);a5h(a.a,a.a.a)}switch(a.c){case 1:a.a.a.G.qE();break;case 2:a.a.a.G.rE();break;case 3:daj(a.a.a);break;case 4:eaj(a.a.a);break;case 5:faj(a.a.a);break;case 6:a.a.a.G.tE();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nkVc(500,1,efn);_.xm=function mbj(){jbj((new nbj(this)).a)};kVc(6093,1,nRm,nbj);_.zm=function obj(){jbj(this.a)};var G2b=wBd(6093);nIm(El)(9);\n//# sourceURL=rstudio-9.js\n")
