$wnd.rstudio.runAsyncCallback20("function poj(a){this.a=a}\nfunction toj(a){this.a=a}\nfunction lpj(a){this.a=a}\nfunction xoj(a,b){this.a=a;this.b=b}\nfunction Nnj(a){Rnj(a,false);Ewf(a.a)}\nfunction hoj(a){a.H.CE();Dm((wm(),vm),new toj(a))}\nfunction rkh(a,b){Aph(a,qhn,'compile_pdf_closed',new tE,b)}\nfunction Dnh(a,b){Aph(a,qhn,'is_compile_pdf_running',new tE,b)}\nfunction $nj(a,b){var c;c=new LRd(b,new poj(a));Dnh(a.d,new roj(a,c))}\nfunction roj(a,b){this.a=a;this.b=b;Duf.call(this,'Closing Compile PDF...')}\nfunction _nj(a,b){Zh(a.g,new mae(false));Nnj(a.g);Znj(a,b.target_file);Tnj(a.g,uwf(1,b.output));b.errors.length>0&&Snj(a.g,b.errors);b.running||Onj(a.g);REe(a.g.a.c.c)}\nfunction hpj(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=upj(a.a.b.a);m6h(a.a,a.a.a)}switch(a.c){case 1:Ufi(a.a.a,a.b[0]);break;case 2:$nj(a.a.a,a.b[0]);break;case 3:_nj(a.a.a,a.b[0]);break;case 4:coj(a.a.a);break;case 5:a.a.a.H.AE();break;case 6:a.a.a.H.BE();break;case 7:doj(a.a.a,a.b[0]);break;case 8:eoj(a.a.a,a.b[0]);break;case 9:foj(a.a.a,a.b[0]);break;case 10:goj(a.a.a,a.b[0]);break;case 11:Znj(a.a.a,a.b[0].a.target_file);break;case 12:hoj(a.a.a);break;case 13:a.a.a.H.DE();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nxVc(6681,1,ASm,poj);_.zm=function qoj(){rkh(this.a.d,new D9e)};var t5b=JBd(6681);xVc(6682,373,{},roj);_.nm=function soj(a){(lQd(a),a)?hVd(2,'Stop Running Compile','There is a PDF compilation currently running. If you close the Compile PDF tab it will be terminated. Are you sure you want to stop the running PDF compilation?',new xoj(this.a,this.b),false):KRd(this.b)};var u5b=JBd(6682);xVc(6683,1,ASm,toj);_.zm=function uoj(){REe(this.a.g.a.c.c)};var v5b=JBd(6683);xVc(6685,1,$Sm,xoj);_.zm=function yoj(){ioj(this.a,this.b)};var x5b=JBd(6685);xVc(286,1,rgn);_.xm=function kpj(){hpj((new lpj(this)).a)};xVc(6209,1,ASm,lpj);_.zm=function mpj(){hpj(this.a)};var J5b=JBd(6209);AJm(El)(20);\n//# sourceURL=rstudio-20.js\n")
