$wnd.rstudio.runAsyncCallback3("function m6h(a){this.a=a}\nfunction o6h(a){this.a=a}\nfunction x6h(a){this.a=a}\nfunction cle(a,b){var c;for(c=0;c<a.p.a.length;c++){if(lbd(a.p,c).xL==b){Ame(a.s,vCd(c));break}}}\nfunction l6h(a,b){this.c=a;this.b=GRh(a.c,Krn,Lrn,QSm).fE();this.a=GRh(a.c,Mrn,Nrn,Orn).fE();Yh(b,new m6h(this),GA?GA:(GA=new _x))}\nfunction j6h(a){var b;b=k6h(a,'weaving Rnw files',a.b,GRh(a.c.c,Krn,Lrn,QSm));b||k6h(a,'LaTeX typesetting',a.a,GRh(a.c.c,Mrn,Nrn,Orn))}\nfunction h6h(a,b,c){var d;d=S0h(a.b.a);hle(d,eUh(Lhg((c7e(),b7e).a)));!!b&&cle(d,b);nle(d,c);ede(d,true);new l6h(a,d);(Tcf()||!!$wnd.remoteDesktop)&&Xcf()}\nfunction t6h(a){try{if(a.c<0)return;!a.a.a&&(a.a.a=Tci(a.a.b.a));switch(a.c){case 1:h6h(a.a.a,null,true);break;case 2:h6h(a.a.a,a.b[0],cBd(a.b[1]));}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nfunction k6h(a,b,c,d){if(aH(c)!==aH(d.fE())&&aH(d.eq())!==aH(d.fE())){WUd(2,'Project Option Unchanged','You changed the global option for '+b+QQm+d.fE()+', however the current project is '+'still configured to use '+d.eq()+'.\\n\\n'+'Do you want to edit the options for the current '+'project as well?',new o6h(a),true);return true}else{return false}}\nkVc(2732,1,{},l6h);var OMb=wBd(2732);kVc(2733,1,lPm,m6h);_.fn=function n6h(a){j6h(this.a)};var MMb=wBd(2733);kVc(2734,1,NRm,o6h);_.zm=function p6h(){F$d(this.a.c.a.Ug)};var NMb=wBd(2734);kVc(615,1,efn);_.xm=function w6h(){t6h((new x6h(this)).a)};kVc(2786,1,nRm,x6h);_.zm=function y6h(){t6h(this.a)};var PMb=wBd(2786);nIm(El)(3);\n//# sourceURL=rstudio-3.js\n")
