$wnd.rstudio.runAsyncCallback16("function Aek(a){var b;z5m[b=++A5m]=Aek;this.a=(B5m[b]=L5m,a);A5m=b-1}\nfunction Zck(a,b){var c;z5m[c=++A5m]=Zck;this.a=(B5m[c]=Xin,a);this.b=b;uhe.call(this);A5m=c-1}\nfunction zck(a){var b,c;z5m[c=++A5m]=zck;b=eOf(new fOf(0,(C5m='Closing Presentation...',B5m[c]=emn,C5m)));oGh((B5m[c]=Xin,a).k,new Zck(a,b));A5m=c-1}\nfunction oGh(a,b){var c;z5m[c=++A5m]=oGh;zLh((B5m[c]=bip,a),Kmo,'close_presentation_pane',(B5m[c]=aJo,new gH),(C5m=(B5m[c]=bip,b),B5m[c]=bJo,C5m));A5m=c-1}\nfunction Cck(a,b){var c;z5m[c=++A5m]=Cck;(B5m[c]=ejn,a).a=b;Pdk((B5m[c]=lcn,a).o,yck(a,(C5m=null,B5m[c]=Jln,C5m)),(C5m=(B5m[c]=D5m,(B5m[c]=lcn,a).a.file_path),B5m[c]=lcn,C5m));A5m=c-1}\nfunction Kck(a){var b;z5m[b=++A5m]=Kck;Pff('Opening Presentation...',(B5m[b]=Wdn,Nvd()));Vyf((B5m[b]=OJn,(B5m[b]=a7m,a).c),new QAf,(C5m=false,B5m[b]=k6m,C5m));A5m=b-1}\nfunction Eck(a,b){var c;z5m[c=++A5m]=Eck;(B5m[c]=R5m,(B5m[c]=q9m,b).slide_index)==0&&ixi((B5m[c]=Z6m,a).o);B5m[c]=ejn,(B5m[c]=m7m,a).a=b;Pdk((B5m[c]=lcn,(B5m[c]=m7m,a).o),yck((B5m[c]=m7m,a),(C5m=null,B5m[c]=Jln,C5m)),(C5m=(B5m[c]=D5m,(B5m[c]=lcn,(B5m[c]=m7m,a).a).file_path),B5m[c]=lcn,C5m));A5m=c-1}\nfunction Jck(a){var b,c;z5m[c=++A5m]=Jck;(B5m[c]=M6m,(B5m[c]=jbn,a).H).OG();!(B5m[c]=oan,!(B5m[c]=Din,a).a)&&(B5m[c]=S5m,(B5m[c]=E5m,a).a.active)&&(b=uee((C5m=(B5m[c]=Tgn,ph((C5m=(B5m[c]=nan,(B5m[c]=Nbn,a).o.d),B5m[c]=J6m,C5m)).contentWindow),B5m[c]=nan,C5m)),(B5m[c]=Nbn,!(!JId(DPn,(B5m[c]=bbn,b))&&!JId('javascript:void(0)',(B5m[c]=Wdn,b)))))&&Cck((B5m[c]=g7m,a),a.a);A5m=c-1}\nfunction wek(b){var c,d,e,f;z5m[e=++A5m]=wek;try{if((B5m[e]=O5m,b).c<0){f=true;return}if(B5m[e]=Z9m,!(B5m[e]=V6m,b).a.a){B5m[e]=c6m,(B5m[e]=c6m,b).a.a=kfk((B5m[e]=K7m,b.a.b.a));msi((B5m[e]=h7m,b).a,b.a.a)}switch((B5m[e]=W7m,b).c){case 1:zck((d=(B5m[e]=e6m,b).a.a,b.b[0],d));break;case 2:Eck((B5m[e]=F6m,b).a.a,b.b[0]);break;case 3:(B5m[e]=$5m,(B5m[e]=m6m,b).a.a.H).MG();break;case 4:(B5m[e]=J9m,(B5m[e]=n8m,b).a.a.H).NG();break;case 5:Jck((B5m[e]=o8m,b).a.a);break;case 6:Kck((c=(B5m[e]=Van,b).a.a,b.b[0],c));break;case 7:(B5m[e]=K6m,(B5m[e]=Kdn,b).a.a.H).PG();}}catch(a){a=UYc(a);A5m=(B5m[e]=d7m,e);throw VYc(a)}finally{(B5m[e]=w9m,b).c<=0&&b.b[0]!=null&&b.b[0].zm();f&&(A5m=e-1)}A5m=e-1}\nvZc(6662,32,{},Zck);_.ru=function _ck(a){var b,c;z5m[c=++A5m]=_ck;Vyf((B5m[c]=OJn,(B5m[c]=ccn,(B5m[c]=$kn,b=this,a,b).a).c),new QAf,(C5m=false,B5m[c]=k6m,C5m));A5m=c-1};_.qu=function $ck(a){var b;z5m[b=++A5m]=$ck;xNf((B5m[b]=Ukn,this.b),(C5m=(B5m[b]=i7m,a.a)?(B5m[b]=T5m,(B5m[b]=e6m,(B5m[b]=Ukn,a).a).c):(B5m[b]=E6m,(B5m[b]=Ukn,a).d),B5m[b]=Ukn,C5m));A5m=b-1};var Rgc=ZGd(6662);vZc(445,1,cko);_.xm=function zek(){var a;z5m[a=++A5m]=zek;wek((B5m[a]=p6m,(new Aek((C5m=this,B5m[a]=L5m,C5m))).a));A5m=a-1};vZc(6226,1,SOn,Aek);_.zm=function Bek(){var a;z5m[a=++A5m]=Bek;wek((B5m[a]=p6m,this.a));A5m=a-1};var ohc=ZGd(6226);y5m(Il)(16);\n//# sourceURL=rstudio-16.js\n")
