$wnd.rstudio.runAsyncCallback16("function iRj(a){var b;hIm[b=++iIm]=iRj;this.a=(jIm[b]=LIm,a);iIm=b-1}\nfunction HPj(a,b){var c;hIm[c=++iIm]=HPj;this.a=(jIm[c]=CVm,a);this.b=b;Fbe.call(this);iIm=c-1}\nfunction hPj(a){var b,c;hIm[c=++iIm]=hPj;b=Euf(new Fuf(0,(kIm='Closing Presentation...',jIm[c]=fZm,kIm)));Yih((jIm[c]=CVm,a).j,new HPj(a,b));iIm=c-1}\nfunction Yih(a,b){var c;hIm[c=++iIm]=Yih;hoh((jIm[c]=wQo,a),UVn,'close_presentation_pane',(jIm[c]=ufo,new oE),(kIm=(jIm[c]=wQo,b),jIm[c]=vfo,kIm));iIm=c-1}\nfunction kPj(a,b){var c;hIm[c=++iIm]=kPj;(jIm[c]=LVm,a).a=b;xQj((jIm[c]=POm,a).n,gPj(a,(kIm=null,jIm[c]=oYm,kIm)),(kIm=(jIm[c]=lIm,(jIm[c]=POm,a).a.file_path),jIm[c]=POm,kIm));iIm=c-1}\nfunction sPj(a){var b;hIm[b=++iIm]=sPj;rYe('Opening Presentation...',(jIm[b]=AQm,Mqd()));uff((jIm[b]=_jn,(jIm[b]=zJm,a).c),new phf,(kIm=false,jIm[b]=HIm,kIm));iIm=b-1}\nfunction mPj(a,b){var c;hIm[c=++iIm]=mPj;(jIm[c]=sIm,(jIm[c]=QLm,b).slide_index)==0&&R9h((jIm[c]=wJm,a).n);jIm[c]=LVm,(jIm[c]=LJm,a).a=b;xQj((jIm[c]=POm,(jIm[c]=LJm,a).n),gPj((jIm[c]=LJm,a),(kIm=null,jIm[c]=oYm,kIm)),(kIm=(jIm[c]=lIm,(jIm[c]=POm,(jIm[c]=LJm,a).a).file_path),jIm[c]=POm,kIm));iIm=c-1}\nfunction rPj(a){var b,c;hIm[c=++iIm]=rPj;(jIm[c]=jJm,(jIm[c]=LNm,a).G).pE();!(jIm[c]=PMm,!(jIm[c]=jVm,a).a)&&(jIm[c]=tIm,(jIm[c]=mIm,a).a.active)&&(b=F8d((kIm=(jIm[c]=yTm,ph((kIm=(jIm[c]=OMm,(jIm[c]=nOm,a).n.d),jIm[c]=fJm,kIm)).contentWindow),jIm[c]=OMm,kIm)),(jIm[c]=nOm,!(!_Cd(Xpn,(jIm[c]=DNm,b))&&!_Cd('javascript:void(0)',(jIm[c]=AQm,b)))))&&kPj((jIm[c]=FJm,a),a.a);iIm=c-1}\nfunction eRj(b){var c,d,e,f;hIm[e=++iIm]=eRj;try{if((jIm[e]=qIm,b).c<0){f=true;return}if(jIm[e]=xMm,!(jIm[e]=sJm,b).a.a){jIm[e]=vIm,(jIm[e]=vIm,b).a.a=URj((jIm[e]=iKm,b.a.b.a));V4h((jIm[e]=GJm,b).a,b.a.a)}switch((jIm[e]=uKm,b).c){case 1:hPj((d=(jIm[e]=xIm,b).a.a,b.b[0],d));break;case 2:mPj((jIm[e]=bJm,b).a.a,b.b[0]);break;case 3:(jIm[e]=mQm,(jIm[e]=JIm,b).a.a.G).nE();break;case 4:(jIm[e]=hMm,(jIm[e]=NKm,b).a.a.G).oE();break;case 5:rPj((jIm[e]=OKm,b).a.a);break;case 6:sPj((c=(jIm[e]=vNm,b).a.a,b.b[0],c));break;case 7:(jIm[e]=gJm,(jIm[e]=oQm,b).a.a.G).qE();}}catch(a){a=CUc(a);iIm=(jIm[e]=CJm,e);throw DUc(a)}finally{(jIm[e]=WLm,b).c<=0&&b.b[0]!=null&&b.b[0].zm();f&&(iIm=e-1)}iIm=e-1}\ndVc(6609,32,{},HPj);_.st=function JPj(a){var b,c;hIm[c=++iIm]=JPj;uff((jIm[c]=_jn,(jIm[c]=GOm,(jIm[c]=FXm,b=this,a,b).a).c),new phf,(kIm=false,jIm[c]=HIm,kIm));iIm=c-1};_.rt=function IPj(a){var b;hIm[b=++iIm]=IPj;Xtf((jIm[b]=zXm,this.b),(kIm=(jIm[b]=HJm,a.a)?(jIm[b]=uIm,(jIm[b]=xIm,(jIm[b]=zXm,a).a).c):(jIm[b]=aJm,(jIm[b]=zXm,a).d),jIm[b]=zXm,kIm));iIm=b-1};var Rcc=pBd(6609);dVc(446,1,mTn);_.xm=function hRj(){var a;hIm[a=++iIm]=hRj;eRj((jIm[a]=NIm,(new iRj((kIm=this,jIm[a]=LIm,kIm))).a));iIm=a-1};dVc(6173,1,kpn,iRj);_.zm=function jRj(){var a;hIm[a=++iIm]=jRj;eRj((jIm[a]=NIm,this.a));iIm=a-1};var odc=pBd(6173);gIm(Gl)(16);\n//# sourceURL=rstudio-16.js\n")
