$wnd.rstudio.runAsyncCallback3("function yti(a){var b;z5m[b=++A5m]=yti;this.a=(B5m[b]=l6m,a);A5m=b-1}\nfunction Ati(a){var b;z5m[b=++A5m]=Ati;this.a=(B5m[b]=a9m,a);A5m=b-1}\nfunction Jti(a){var b;z5m[b=++A5m]=Jti;this.a=(B5m[b]=R5m,a);A5m=b-1}\nfunction Nqe(a,b){var c,d;z5m[d=++A5m]=Nqe;for(B5m[d]=Fan,c=0;(B5m[d]=Fan,c)<(B5m[d]=den,a.p.a).length;B5m[d]=Fan,c++){if(cgd((B5m[d]=$dn,a).p,c).vO==b){Bte((B5m[d]=R7m,(B5m[d]=X7m,a).s),YHd((C5m=(B5m[d]=X7m,c),B5m[d]=R7m,C5m)));break}}A5m=d-1}\nfunction xti(a,b){var c;z5m[c=++A5m]=xti;this.c=(B5m[c]=i7m,a);this.b=(C5m=Rci((B5m[c]=Gan,a).c,cFo,dFo,(C5m=CQn,B5m[c]=mtn,C5m)),B5m[c]=Gan,C5m).BG();this.a=(C5m=Rci((B5m[c]=E6m,a).c,eFo,fFo,(C5m=gFo,B5m[c]=ptn,C5m)),B5m[c]=E6m,C5m).BG();$h((B5m[c]=l6m,b),new yti(this),(C5m=(B5m[c]=p6m,tD)?tD:(tD=new OA),B5m[c]=$pn,C5m));A5m=c-1}\nfunction vti(a){var b,c;z5m[c=++A5m]=vti;b=wti((B5m[c]=m6m,a),'weaving Rnw files',(B5m[c]=Ybn,a).b,(C5m=Rci((B5m[c]=n8m,a).c.c,cFo,dFo,(C5m=CQn,B5m[c]=mtn,C5m)),B5m[c]=m6m,C5m));(B5m[c]=O6m,b)||wti((B5m[c]=Wbn,a),'LaTeX typesetting',(B5m[c]=Q6m,a).a,(C5m=Rci((B5m[c]=Van,a).c.c,eFo,fFo,(C5m=gFo,B5m[c]=ptn,C5m)),B5m[c]=Wbn,C5m));A5m=c-1}\nfunction tti(a,b,c){var d,e;z5m[e=++A5m]=tti;B5m[e]=gbn,d=boi((B5m[e]=Win,(B5m[e]=gbn,a).b.a));Sqe((B5m[e]=N6m,d),(C5m=pfi(YCg((B5m[e]=Y6m,(B5m[e]=xjn,tqf(),(B5m[e]=N6m,sqf)).a))),B5m[e]=N6m,C5m));!(B5m[e]=oan,!(B5m[e]=S6m,b))&&Nqe((B5m[e]=o6m,d),b);Yqe((B5m[e]=n6m,d),c);Oie((B5m[e]=L5m,d),(C5m=true,B5m[e]=Udn,C5m));new xti((B5m[e]=U6m,a),d);((B5m[e]=g6m,iwf())||!!(B5m[e]=Jan,$wnd).remoteDesktop)&&(B5m[e]=c6m,mwf());A5m=e-1}\nfunction Fti(b){var c,d;z5m[c=++A5m]=Fti;try{if((B5m[c]=W5m,b).c<0){d=true;return}(B5m[c]=Z9m,!(B5m[c]=M6m,b).a.a)&&(B5m[c]=j6m,(B5m[c]=j6m,b).a.a=dAi((B5m[c]=Vin,b.a.b.a)));switch((B5m[c]=k6m,b).c){case 1:tti((B5m[c]=D8m,b).a.a,null,(C5m=true,B5m[c]=B8m,C5m));break;case 2:tti((B5m[c]=S6m,b).a.a,b.b[0],FGd(b.b[1]));}}catch(a){a=UYc(a);A5m=(B5m[c]=e7m,c);throw VYc(a)}finally{(B5m[c]=p6m,b).c<=0&&b.b[0]!=null&&b.b[0].zm();d&&(A5m=c-1)}A5m=c-1}\nfunction wti(a,b,c,d){var e;z5m[e=++A5m]=wti;if(RJ((B5m[e]=Gdn,c))!==RJ(d.BG())&&RJ((B5m[e]=Qbn,d).Gq())!==RJ(d.BG())){E$d(2,'Project Option Unchanged','You changed the global option for '+(B5m[e]=$8m,b)+tOn+(B5m[e]=_8m,d).BG()+', however the current project is '+'still configured to use '+(B5m[e]=Man,d).Gq()+'.\\n\\n'+'Do you want to edit the options for the current '+'project as well?',new Ati((B5m[e]=a9m,a)),(C5m=true,B5m[e]=E8m,C5m));A5m=e-1;return true}else{A5m=e-1;return false}A5m=e-1}\nvZc(2761,1,{},xti);var vQb=ZGd(2761);vZc(2762,1,LLn,yti);_.Gn=function zti(a){var b;z5m[b=++A5m]=zti;vti((B5m[b]=l6m,this.a));A5m=b-1};var tQb=ZGd(2762);vZc(2763,1,qPn,Ati);_.zm=function Bti(){var a;z5m[a=++A5m]=Bti;n4d((C5m=(B5m[a]='6339',(B5m[a]=a9m,this.a).c.a.Ug),B5m[a]=a9m,C5m));A5m=a-1};var uQb=ZGd(2763);vZc(617,1,cko);_.xm=function Iti(){var a;z5m[a=++A5m]=Iti;Fti((B5m[a]=V5m,(new Jti((C5m=this,B5m[a]=R5m,C5m))).a));A5m=a-1};vZc(2815,1,SOn,Jti);_.zm=function Kti(){var a;z5m[a=++A5m]=Kti;Fti((B5m[a]=V5m,this.a));A5m=a-1};var wQb=ZGd(2815);y5m(Il)(3);\n//# sourceURL=rstudio-3.js\n")
