$wnd.rstudio.runAsyncCallback15("function Dgi(){}\nfunction Bgi(a){this.a=a}\nfunction Ggi(a){this.a=a}\nfunction Igi(a){this.a=a}\nfunction Ihi(a){this.a=a}\nfunction Ufi(a){this.a=a}\nfunction eEf(a){this.a=a}\nfunction xfi(a){Jfi(a,new Ggi(a))}\nfunction Cfi(a){CCf(a.b,new Igi(a))}\nfunction Bfi(a){wVj(a.k,new Bgi(a),new Dgi,Jcn)}\nfunction Efi(a){wVj(a.k,new vgi(a,null),new xgi,njn)}\nfunction Ffi(a,b){Bff(a.d,new eyi(b,true),false)}\nfunction NCf(a,b){($Pd(b),b)&&Hfi(a.a,fbo,'')}\nfunction Wfi(a,b){this.a=a;this.b=b;pvf.call(this)}\nfunction Fgi(a,b){Ffi(a.a,'devtools::load_all(\"'+b+'\")')}\nfunction Jjh(a,b){ooh(a,dgn,'devtools_load_all_path',new tE,b)}\nfunction Jfi(a,b){a.c!=null?Fgi(b,a.c):Jjh(a.i,new Wfi(a,b))}\nfunction Dfi(a){a.G.sE();Dm((wm(),vm),new Ufi(a))}\nfunction Sfi(){nuf.call(this,'Terminating Build...')}\nfunction CCf(a,b){oCf(a,ebo,ebo,FEf(a.g.b.package_dependencies,'roxygen'),bCf(a,'roxygen'),false,new eEf(b))}\nfunction ufi(a,b){var c,d;qwf(a.p.e,null);d=b.outputs;for(c=0;c<d.length;c++)Rei(a.p,d[c]);b.errors.length>0&&Qei(a.p,b.errors_base_dir,b.errors,false,0,true,b.type);b.running?Z$d(a.a.Cj,true,false):pwf(a.p.e);EEe(a.p.e.c.c)}\nfunction Ehi(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=hii(a.a.b.a);a5h(a.a,a.a.a)}switch(a.c){case 1:ufi(a.a.a,a.b[0]);break;case 2:a.a.a.G.qE();break;case 3:a.a.a.G.rE();break;case 4:Hfi(a.a.a,oVn,'');break;case 5:Hfi(a.a.a,'build-binary-package','');break;case 6:Hfi(a.a.a,'build-source-package','');break;case 7:Hfi(a.a.a,'check-package','');break;case 8:Hfi(a.a.a,'clean-all','');break;case 9:Bfi(a.a.a);break;case 10:Hfi(a.a.a,pVn,'');break;case 11:Cfi(a.a.a);break;case 12:Dfi(a.a.a);break;case 13:Efi(a.a.a);break;case 14:qph(a.a.a.i,new Sfi);break;case 15:Hfi(a.a.a,'test-package','');break;case 18:a.a.a.G.tE();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nvar ebo='Building package documentation',fbo='roxygenize-package';kVc(2154,1,iRm,eEf);_.os=function fEf(a){NCf(this.a,a)};var zgb=wBd(2154);kVc(6595,373,{},Sfi);_.nm=function Tfi(a){($Pd(a),a)||GUc().nA(3,'Error Terminating Build','Unable to terminate build. Please try again.').oA()};var vPb=wBd(6595);kVc(6596,1,nRm,Ufi);_.zm=function Vfi(){EEe(this.a.p.e.c.c)};var wPb=wBd(6596);kVc(6597,52,{},Wfi);_.vt=function Xfi(a){this.a.c=a;Fgi(this.b,this.a.c)};var xPb=wBd(6597);kVc(6588,1,nRm,Bgi);_.zm=function Cgi(){xfi(this.a)};var NPb=wBd(6588);kVc(6589,1,nRm,Dgi);_.zm=function Egi(){};var OPb=wBd(6589);kVc(6587,1,iRm,Ggi);_.os=function Hgi(a){Fgi(this,a)};var PPb=wBd(6587);kVc(6590,1,nRm,Igi);_.zm=function Jgi(){Hfi(this.a,fbo,'')};var QPb=wBd(6590);kVc(251,1,efn);_.xm=function Hhi(){Ehi((new Ihi(this)).a)};kVc(6158,1,nRm,Ihi);_.zm=function Jhi(){Ehi(this.a)};var kQb=wBd(6158);nIm(El)(15);\n//# sourceURL=rstudio-15.js\n")
