$wnd.rstudio.runAsyncCallback7("function aVj(a){this.a=a}\nfunction kUj(a,b){this.a=a;this.b=b}\nfunction gUj(a,b){b==null?m5d(a,Fuo):m5d(a,b)}\nfunction vUj(a,b){Zh(a.d,new Qfe(false));mUj(a.d,b,0)}\nfunction WJh(a,b){GLh(a,WIn,'markers_tab_closed',new lH,b)}\nfunction hUj(a,b){var c,d,e,f,g,h,i;d=a.p;trd(d.n);for(g=b,h=0,i=g.length;h<i;++h){f=g[h];c=new kUj(a,f);e=new d_c(b_c(new c_c,f).a.a);Pcf(d,new Asd(e,c))}}\nfunction mUj(a,b,c){var d;Omg(a.b);gUj(a.c,null);hUj(a.c,bJ(YI(QX,1),o6m,2,6,[]));if(b.markers){d=b.markers;Smg(a.b,null,d.base_path,d.markers,c,false);hUj(a.c,kne(b.names));gUj(a.c,d.name)}}\nfunction uUj(a,b){var c,d,e,f,g;g=b.a.markers_state;if(g.markers){Zh(a.d,new Qfe(true));mUj(a.d,b.a.markers_state,b.a.auto_select);e=g.markers;if(e){d=e.markers;if(d.length>0){f=null;c=b.a.auto_select;c==1?(f=d[0]):c==2&&(f=Amg(d));!!f&&_2f(a.b,(Ohe(),eie(f.path,false,-1,0)),zZd(f.line,f.column),false)}}}else{Zh(a.d,new Jfe)}}\nfunction YUj(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=jVj(a.a.b.a);tsi(a.a,a.a.a)}switch(a.c){case 1:tUj(a.a.a);break;case 2:a.a.a.H.PG();break;case 3:a.a.a.H.QG();break;case 4:WJh(a.a.a.c,new Osf);break;case 5:uUj(a.a.a,a.b[0]);break;case 6:a.a.a.H.RG();break;case 7:a.a.a.H.SG();break;case 8:vUj(a.a.a,a.b[0]);}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nCZc(7304,1,e8m,kUj);_.zm=function lUj(){TD(this.a,this.b)};var Abc=eHd(7304);CZc(418,1,XHn);_.xm=function _Uj(){YUj((new aVj(this)).a)};CZc(6050,1,Oen,aVj);_.zm=function bVj(){YUj(this.a)};var Nbc=eHd(6050);F5m(Gl)(7);\n//# sourceURL=rstudio-7.js\n")
