$wnd.rstudio.runAsyncCallback22("function YUj(a){this.a=a}\nfunction pUj(a,b){this.a=a;this.b=b}\nfunction bUj(a,b){a.k?A$d(4,'Stop R Markdown Rendering',\"The rendering of '\"+a.g+\"' is in progress. Do you \"+'want to terminate and close the tab?',false,new pUj(a,b),null,null,VDn,Vdn,true):b.zm()}\nfunction UUj(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=$Uj(a.a.b.a);gri(a.a,a.a.a)}switch(a.c){case 1:PAi(a.a.a,a.b[0]);break;case 2:bUj(a.a.a,a.b[0]);break;case 3:cUj(a.a.a);break;case 4:a.a.a.G.FG();break;case 5:a.a.a.G.GG();break;case 6:dUj(a.a.a,a.b[0]);break;case 7:eUj(a.a.a,a.b[0]);break;case 8:fUj(a.a.a,a.b[0]);break;case 9:gUj(a.a.a,a.b[0]);break;case 10:a.a.a.G.HG();break;case 11:a.a.a.G.IG();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\npZc(6722,1,_dn,pUj);_.zm=function qUj(){hUj(this.a);this.b.zm()};var Kbc=TGd(6722);pZc(310,1,KGn);_.xm=function XUj(){UUj((new YUj(this)).a)};pZc(6242,1,Bdn,YUj);_.zm=function ZUj(){UUj(this.a)};var Tbc=TGd(6242);s4m(Gl)(22);\n//# sourceURL=rstudio-22.js\n")
