$wnd.rstudio.runAsyncCallback16("function ndk(a){var b;m4m[b=++n4m]=ndk;this.a=(o4m[b]=y4m,a);n4m=b-1}\nfunction Mbk(a,b){var c;m4m[c=++n4m]=Mbk;this.a=(o4m[c]=Jhn,a);this.b=b;hhe.call(this);n4m=c-1}\nfunction mbk(a){var b,c;m4m[c=++n4m]=mbk;b=QNf(new RNf(0,(p4m='Closing Presentation...',o4m[c]=Tkn,p4m)));cFh((o4m[c]=Jhn,a).j,new Mbk(a,b));n4m=c-1}\nfunction cFh(a,b){var c;m4m[c=++n4m]=cFh;nKh((o4m[c]=Rgp,a),xlo,'close_presentation_pane',(o4m[c]=QHo,new gH),(p4m=(o4m[c]=Rgp,b),o4m[c]=RHo,p4m));n4m=c-1}\nfunction pbk(a,b){var c;m4m[c=++n4m]=pbk;(o4m[c]=Shn,a).a=b;Cck((o4m[c]=$an,a).n,lbk(a,(p4m=null,o4m[c]=wkn,p4m)),(p4m=(o4m[c]=q4m,(o4m[c]=$an,a).a.file_path),o4m[c]=$an,p4m));n4m=c-1}\nfunction xbk(a){var b;m4m[b=++n4m]=xbk;Cff('Opening Presentation...',(o4m[b]=Jcn,Avd()));Fyf((o4m[b]=BIn,(o4m[b]=P5m,a).c),new AAf,(p4m=false,o4m[b]=Z4m,p4m));n4m=b-1}\nfunction rbk(a,b){var c;m4m[c=++n4m]=rbk;(o4m[c]=D4m,(o4m[c]=d8m,b).slide_index)==0&&Yvi((o4m[c]=M5m,a).n);o4m[c]=Shn,(o4m[c]=_5m,a).a=b;Cck((o4m[c]=$an,(o4m[c]=_5m,a).n),lbk((o4m[c]=_5m,a),(p4m=null,o4m[c]=wkn,p4m)),(p4m=(o4m[c]=q4m,(o4m[c]=$an,(o4m[c]=_5m,a).a).file_path),o4m[c]=$an,p4m));n4m=c-1}\nfunction wbk(a){var b,c;m4m[c=++n4m]=wbk;(o4m[c]=z5m,(o4m[c]=X9m,a).G).EG();!(o4m[c]=b9m,!(o4m[c]=phn,a).a)&&(o4m[c]=E4m,(o4m[c]=r4m,a).a.active)&&(b=hee((p4m=(o4m[c]=Gfn,ph((p4m=(o4m[c]=a9m,(o4m[c]=Aan,a).n.d),o4m[c]=w5m,p4m)).contentWindow),o4m[c]=a9m,p4m)),(o4m[c]=Aan,!(!wId(pOn,(o4m[c]=P9m,b))&&!wId('javascript:void(0)',(o4m[c]=Jcn,b)))))&&pbk((o4m[c]=V5m,a),a.a);n4m=c-1}\nfunction jdk(b){var c,d,e,f;m4m[e=++n4m]=jdk;try{if((o4m[e]=B4m,b).c<0){f=true;return}if(o4m[e]=M8m,!(o4m[e]=I5m,b).a.a){o4m[e]=Q4m,(o4m[e]=Q4m,b).a.a=Zdk((o4m[e]=x6m,b.a.b.a));_qi((o4m[e]=W5m,b).a,b.a.a)}switch((o4m[e]=J6m,b).c){case 1:mbk((d=(o4m[e]=S4m,b).a.a,b.b[0],d));break;case 2:rbk((o4m[e]=s5m,b).a.a,b.b[0]);break;case 3:(o4m[e]=M4m,(o4m[e]=_4m,b).a.a.G).CG();break;case 4:(o4m[e]=w8m,(o4m[e]=a7m,b).a.a.G).DG();break;case 5:wbk((o4m[e]=b7m,b).a.a);break;case 6:xbk((c=(o4m[e]=H9m,b).a.a,b.b[0],c));break;case 7:(o4m[e]=x5m,(o4m[e]=xcn,b).a.a.G).FG();}}catch(a){a=HYc(a);n4m=(o4m[e]=S5m,e);throw IYc(a)}finally{(o4m[e]=j8m,b).c<=0&&b.b[0]!=null&&b.b[0].zm();f&&(n4m=e-1)}n4m=e-1}\niZc(6650,32,{},Mbk);_.ru=function Obk(a){var b,c;m4m[c=++n4m]=Obk;Fyf((o4m[c]=BIn,(o4m[c]=Ran,(o4m[c]=Njn,b=this,a,b).a).c),new AAf,(p4m=false,o4m[c]=Z4m,p4m));n4m=c-1};_.qu=function Nbk(a){var b;m4m[b=++n4m]=Nbk;hNf((o4m[b]=Hjn,this.b),(p4m=(o4m[b]=X5m,a.a)?(o4m[b]=F4m,(o4m[b]=S4m,(o4m[b]=Hjn,a).a).c):(o4m[b]=r5m,(o4m[b]=Hjn,a).d),o4m[b]=Hjn,p4m));n4m=b-1};var Fgc=MGd(6650);iZc(445,1,Rio);_.xm=function mdk(){var a;m4m[a=++n4m]=mdk;jdk((o4m[a]=c5m,(new ndk((p4m=this,o4m[a]=y4m,p4m))).a));n4m=a-1};iZc(6214,1,ENn,ndk);_.zm=function odk(){var a;m4m[a=++n4m]=odk;jdk((o4m[a]=c5m,this.a));n4m=a-1};var chc=MGd(6214);l4m(Il)(16);\n//# sourceURL=rstudio-16.js\n")
