$wnd.rstudio.runAsyncCallback9("function Acj(a){this.a=a}\nfunction sbj(a){a.H.CE();KIe(a.i.n)}\nfunction qbj(a){ibi(a.i);Etf(a.a,'Load History','loadhistory')}\nfunction rbj(a){ibi(a.i);Jtf(a.a,'Save History As','.Rhistory',false,'savehistory')}\nfunction wcj(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=ddj(a.a.b.a);m6h(a.a,a.a.a)}switch(a.c){case 1:a.a.a.H.AE();break;case 2:a.a.a.H.BE();break;case 3:qbj(a.a.a);break;case 4:rbj(a.a.a);break;case 5:sbj(a.a.a);break;case 6:a.a.a.H.DE();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nxVc(500,1,rgn);_.xm=function zcj(){wcj((new Acj(this)).a)};xVc(6105,1,ASm,Acj);_.zm=function Bcj(){wcj(this.a)};var S2b=JBd(6105);AJm(El)(9);\n//# sourceURL=rstudio-9.js\n")
