$wnd.rstudio.runAsyncCallback20("function cnj(a){this.a=a}\nfunction gnj(a){this.a=a}\nfunction $nj(a){this.a=a}\nfunction knj(a,b){this.a=a;this.b=b}\nfunction Amj(a){Emj(a,false);owf(a.a)}\nfunction Wmj(a){a.G.sE();Dm((wm(),vm),new gnj(a))}\nfunction Nmj(a,b){var c;c=new yRd(b,new cnj(a));rmh(a.d,new enj(a,c))}\nfunction fjh(a,b){ooh(a,dgn,'compile_pdf_closed',new tE,b)}\nfunction rmh(a,b){ooh(a,dgn,'is_compile_pdf_running',new tE,b)}\nfunction enj(a,b){this.a=a;this.b=b;nuf.call(this,'Closing Compile PDF...')}\nfunction Omj(a,b){Zh(a.g,new _9d(false));Amj(a.g);Mmj(a,b.target_file);Gmj(a.g,ewf(1,b.output));b.errors.length>0&&Fmj(a.g,b.errors);b.running||Bmj(a.g);EEe(a.g.a.c.c)}\nfunction Wnj(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=hoj(a.a.b.a);a5h(a.a,a.a.a)}switch(a.c){case 1:Iei(a.a.a,a.b[0]);break;case 2:Nmj(a.a.a,a.b[0]);break;case 3:Omj(a.a.a,a.b[0]);break;case 4:Rmj(a.a.a);break;case 5:a.a.a.G.qE();break;case 6:a.a.a.G.rE();break;case 7:Smj(a.a.a,a.b[0]);break;case 8:Tmj(a.a.a,a.b[0]);break;case 9:Umj(a.a.a,a.b[0]);break;case 10:Vmj(a.a.a,a.b[0]);break;case 11:Mmj(a.a.a,a.b[0].a.target_file);break;case 12:Wmj(a.a.a);break;case 13:a.a.a.G.tE();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nkVc(6669,1,nRm,cnj);_.zm=function dnj(){fjh(this.a.d,new q9e)};var h5b=wBd(6669);kVc(6670,373,{},enj);_.nm=function fnj(a){($Pd(a),a)?WUd(2,'Stop Running Compile','There is a PDF compilation currently running. If you close the Compile PDF tab it will be terminated. Are you sure you want to stop the running PDF compilation?',new knj(this.a,this.b),false):xRd(this.b)};var i5b=wBd(6670);kVc(6671,1,nRm,gnj);_.zm=function hnj(){EEe(this.a.g.a.c.c)};var j5b=wBd(6671);kVc(6673,1,NRm,knj);_.zm=function lnj(){Xmj(this.a,this.b)};var l5b=wBd(6673);kVc(286,1,efn);_.xm=function Znj(){Wnj((new $nj(this)).a)};kVc(6197,1,nRm,$nj);_.zm=function _nj(){Wnj(this.a)};var x5b=wBd(6197);nIm(El)(20);\n//# sourceURL=rstudio-20.js\n")
