$wnd.rstudio.runAsyncCallback22("function jWj(a){this.a=a}\nfunction CVj(a,b){this.a=a;this.b=b}\nfunction oVj(a,b){a.k?N$d(4,'Stop R Markdown Rendering',\"The rendering of '\"+a.g+\"' is in progress. Do you \"+'want to terminate and close the tab?',false,new CVj(a,b),null,null,hFn,gfn,true):b.zm()}\nfunction fWj(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=lWj(a.a.b.a);tsi(a.a,a.a.a)}switch(a.c){case 1:_Bi(a.a.a,a.b[0]);break;case 2:oVj(a.a.a,a.b[0]);break;case 3:pVj(a.a.a);break;case 4:a.a.a.H.PG();break;case 5:a.a.a.H.QG();break;case 6:qVj(a.a.a,a.b[0]);break;case 7:rVj(a.a.a,a.b[0]);break;case 8:sVj(a.a.a,a.b[0]);break;case 9:tVj(a.a.a,a.b[0]);break;case 10:a.a.a.H.RG();break;case 11:a.a.a.H.SG();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nCZc(6734,1,mfn,CVj);_.zm=function DVj(){uVj(this.a);this.b.zm()};var Wbc=eHd(6734);CZc(310,1,XHn);_.xm=function iWj(){fWj((new jWj(this)).a)};CZc(6254,1,Oen,jWj);_.zm=function kWj(){fWj(this.a)};var dcc=eHd(6254);F5m(Gl)(22);\n//# sourceURL=rstudio-22.js\n")
