$wnd.rstudio.runAsyncCallback3("function f6h(a){var b;hIm[b=++iIm]=f6h;this.a=(jIm[b]=IIm,a);iIm=b-1}\nfunction q6h(a){var b;hIm[b=++iIm]=q6h;this.a=(jIm[b]=sIm,a);iIm=b-1}\nfunction h6h(a){var b;hIm[b=++iIm]=h6h;this.a=(jIm[b]=ALm,a);iIm=b-1}\nfunction Xke(a,b){var c,d;hIm[d=++iIm]=Xke;for(jIm[d]=eNm,c=0;(jIm[d]=eNm,c)<(jIm[d]=JQm,a.p.a).length;jIm[d]=eNm,c++){if(ebd((jIm[d]=EQm,a).p,c).uL==b){tme((jIm[d]=pKm,(jIm[d]=vKm,a).s),oCd((kIm=(jIm[d]=vKm,c),jIm[d]=pKm,kIm)));break}}iIm=d-1}\nfunction e6h(a,b){var c;hIm[c=++iIm]=e6h;this.c=(jIm[c]=HJm,a);this.b=(kIm=zRh((jIm[c]=gNm,a).c,wbo,xbo,(kIm=Wqn,jIm[c]=U2m,kIm)),jIm[c]=gNm,kIm).cE();this.a=(kIm=zRh((jIm[c]=aJm,a).c,ybo,zbo,(kIm=Abo,jIm[c]=X2m,kIm)),jIm[c]=aJm,kIm).cE();$h((jIm[c]=IIm,b),new f6h(this),(kIm=(jIm[c]=NIm,BA)?BA:(BA=new Wx),jIm[c]=t_m,kIm));iIm=c-1}\nfunction c6h(a){var b,c;hIm[c=++iIm]=c6h;b=d6h((jIm[c]=JIm,a),'weaving Rnw files',(jIm[c]=zOm,a).b,(kIm=zRh((jIm[c]=NKm,a).c.c,wbo,xbo,(kIm=Wqn,jIm[c]=U2m,kIm)),jIm[c]=JIm,kIm));(jIm[c]=lJm,b)||d6h((jIm[c]=xOm,a),'LaTeX typesetting',(jIm[c]=nJm,a).a,(kIm=zRh((jIm[c]=vNm,a).c.c,ybo,zbo,(kIm=Abo,jIm[c]=X2m,kIm)),jIm[c]=xOm,kIm));iIm=c-1}\nfunction a6h(a,b,c){var d,e;hIm[e=++iIm]=a6h;jIm[e]=INm,d=L0h((jIm[e]=BVm,(jIm[e]=INm,a).b.a));ale((jIm[e]=kJm,d),(kIm=ZTh(Ehg((jIm[e]=vJm,(jIm[e]=cWm,X6e(),(jIm[e]=kJm,W6e)).a))),jIm[e]=kJm,kIm));!(jIm[e]=PMm,!(jIm[e]=pJm,b))&&Xke((jIm[e]=MIm,d),b);gle((jIm[e]=KIm,d),c);Zce((jIm[e]=LIm,d),(kIm=true,jIm[e]=yQm,kIm));new e6h((jIm[e]=rJm,a),d);((jIm[e]=BIm,Mcf())||!!(jIm[e]=jNm,$wnd).remoteDesktop)&&(jIm[e]=vIm,Qcf());iIm=e-1}\nfunction m6h(b){var c,d;hIm[c=++iIm]=m6h;try{if((jIm[c]=FIm,b).c<0){d=true;return}(jIm[c]=xMm,!(jIm[c]=jJm,b).a.a)&&(jIm[c]=GIm,(jIm[c]=GIm,b).a.a=Mci((jIm[c]=AVm,b.a.b.a)));switch((jIm[c]=HIm,b).c){case 1:a6h((jIm[c]=bLm,b).a.a,null,(kIm=true,jIm[c]=_Km,kIm));break;case 2:a6h((jIm[c]=pJm,b).a.a,b.b[0],XAd(b.b[1]));}}catch(a){a=CUc(a);iIm=(jIm[c]=DJm,c);throw DUc(a)}finally{(jIm[c]=NIm,b).c<=0&&b.b[0]!=null&&b.b[0].zm();d&&(iIm=c-1)}iIm=c-1}\nfunction d6h(a,b,c,d){var e;hIm[e=++iIm]=d6h;if(XG((jIm[e]=jQm,c))!==XG(d.cE())&&XG((jIm[e]=qOm,d).bq())!==XG(d.cE())){PUd(2,'Project Option Unchanged','You changed the global option for '+(jIm[e]=yLm,b)+Non+(jIm[e]=zLm,d).cE()+', however the current project is '+'still configured to use '+(jIm[e]=mNm,d).bq()+'.\\n\\n'+'Do you want to edit the options for the current '+'project as well?',new h6h((jIm[e]=ALm,a)),(kIm=true,jIm[e]=cLm,kIm));iIm=e-1;return true}else{iIm=e-1;return false}iIm=e-1}\ndVc(2731,1,{},e6h);var HMb=pBd(2731);dVc(2732,1,bmn,f6h);_.cn=function g6h(a){var b;hIm[b=++iIm]=g6h;c6h((jIm[b]=IIm,this.a));iIm=b-1};var FMb=pBd(2732);dVc(2733,1,Kpn,h6h);_.zm=function i6h(){var a;hIm[a=++iIm]=i6h;y$d((kIm=(jIm[a]='6339',(jIm[a]=ALm,this.a).c.a.Ug),jIm[a]=ALm,kIm));iIm=a-1};var GMb=pBd(2733);dVc(615,1,mTn);_.xm=function p6h(){var a;hIm[a=++iIm]=p6h;m6h((jIm[a]=DIm,(new q6h((kIm=this,jIm[a]=sIm,kIm))).a));iIm=a-1};dVc(2785,1,kpn,q6h);_.zm=function r6h(){var a;hIm[a=++iIm]=r6h;m6h((jIm[a]=DIm,this.a));iIm=a-1};var IMb=pBd(2785);gIm(Gl)(3);\n//# sourceURL=rstudio-3.js\n")
