$wnd.rstudio.runAsyncCallback7("function Ixj(a){this.a=a}\nfunction Swj(a,b){this.a=a;this.b=b}\nfunction Owj(a,b){b==null?K_d(a,R1n):K_d(a,b)}\nfunction bxj(a,b){Zh(a.d,new mae(false));Uwj(a.d,b,0)}\nfunction Qnh(a,b){Aph(a,qhn,'markers_tab_closed',new tE,b)}\nfunction Pwj(a,b){var c,d,e,f,g,h,i;d=a.p;Fmd(d.n);for(g=b,h=0,i=g.length;h<i;++h){f=g[h];c=new Swj(a,f);e=new RWc(PWc(new QWc,f).a.a);EVe(d,new Mnd(e,c))}}\nfunction Uwj(a,b,c){var d;B3f(a.b);Owj(a.c,null);Pwj(a.c,hG(cG(GU,1),jKm,2,6,[]));if(b.markers){d=b.markers;F3f(a.b,null,d.base_path,d.markers,c,false);Pwj(a.c,Hhe(b.names));Owj(a.c,d.name)}}\nfunction axj(a,b){var c,d,e,f,g;g=b.a.markers_state;if(g.markers){Zh(a.d,new mae(true));Uwj(a.d,b.a.markers_state,b.a.auto_select);e=g.markers;if(e){d=e.markers;if(d.length>0){f=null;c=b.a.auto_select;c==1?(f=d[0]):c==2&&(f=n3f(d));!!f&&OLf(a.b,(kce(),Cce(f.path,false,-1,0)),XTd(f.line,f.column),false)}}}else{Zh(a.d,new fae)}}\nfunction Exj(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=Rxj(a.a.b.a);m6h(a.a,a.a.a)}switch(a.c){case 1:_wj(a.a.a);break;case 2:a.a.a.H.AE();break;case 3:a.a.a.H.BE();break;case 4:Qnh(a.a.a.c,new D9e);break;case 5:axj(a.a.a,a.b[0]);break;case 6:a.a.a.H.CE();break;case 7:a.a.a.H.DE();break;case 8:bxj(a.a.a,a.b[0]);}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nxVc(7260,1,aMm,Swj);_.zm=function Twj(){_A(this.a,this.b)};var P7b=JBd(7260);xVc(419,1,rgn);_.xm=function Hxj(){Exj((new Ixj(this)).a)};xVc(6009,1,ASm,Ixj);_.zm=function Jxj(){Exj(this.a)};var a8b=JBd(6009);AJm(El)(7);\n//# sourceURL=rstudio-7.js\n")
