$wnd.rstudio.runAsyncCallback3("function msi(a){var b;m4m[b=++n4m]=msi;this.a=(o4m[b]=$4m,a);n4m=b-1}\nfunction xsi(a){var b;m4m[b=++n4m]=xsi;this.a=(o4m[b]=D4m,a);n4m=b-1}\nfunction osi(a){var b;m4m[b=++n4m]=osi;this.a=(o4m[b]=P7m,a);n4m=b-1}\nfunction Aqe(a,b){var c,d;m4m[d=++n4m]=Aqe;for(o4m[d]=r9m,c=0;(o4m[d]=r9m,c)<(o4m[d]=Scn,a.p.a).length;o4m[d]=r9m,c++){if(Rfd((o4m[d]=Ncn,a).p,c).lO==b){ote((o4m[d]=E6m,(o4m[d]=K6m,a).s),LHd((p4m=(o4m[d]=K6m,c),o4m[d]=E6m,p4m)));break}}n4m=d-1}\nfunction lsi(a,b){var c;m4m[c=++n4m]=lsi;this.c=(o4m[c]=X5m,a);this.b=(p4m=Fbi((o4m[c]=s9m,a).c,SDo,TDo,(p4m=oPn,o4m[c]=_rn,p4m)),o4m[c]=s9m,p4m).rG();this.a=(p4m=Fbi((o4m[c]=r5m,a).c,UDo,VDo,(p4m=WDo,o4m[c]=csn,p4m)),o4m[c]=r5m,p4m).rG();$h((o4m[c]=$4m,b),new msi(this),(p4m=(o4m[c]=c5m,tD)?tD:(tD=new OA),o4m[c]=Non,p4m));n4m=c-1}\nfunction jsi(a){var b,c;m4m[c=++n4m]=jsi;b=ksi((o4m[c]=_4m,a),'weaving Rnw files',(o4m[c]=Lan,a).b,(p4m=Fbi((o4m[c]=a7m,a).c.c,SDo,TDo,(p4m=oPn,o4m[c]=_rn,p4m)),o4m[c]=_4m,p4m));(o4m[c]=B5m,b)||ksi((o4m[c]=Jan,a),'LaTeX typesetting',(o4m[c]=D5m,a).a,(p4m=Fbi((o4m[c]=H9m,a).c.c,UDo,VDo,(p4m=WDo,o4m[c]=csn,p4m)),o4m[c]=Jan,p4m));n4m=c-1}\nfunction hsi(a,b,c){var d,e;m4m[e=++n4m]=hsi;o4m[e]=U9m,d=Rmi((o4m[e]=Ihn,(o4m[e]=U9m,a).b.a));Fqe((o4m[e]=A5m,d),(p4m=dei(MBg((o4m[e]=L5m,(o4m[e]=jin,gqf(),(o4m[e]=A5m,fqf)).a))),o4m[e]=A5m,p4m));!(o4m[e]=b9m,!(o4m[e]=F5m,b))&&Aqe((o4m[e]=b5m,d),b);Lqe((o4m[e]=a5m,d),c);Bie((o4m[e]=y4m,d),(p4m=true,o4m[e]=Hcn,p4m));new lsi((o4m[e]=H5m,a),d);((o4m[e]=V4m,Xvf())||!!(o4m[e]=v9m,$wnd).remoteDesktop)&&(o4m[e]=Q4m,_vf());n4m=e-1}\nfunction tsi(b){var c,d;m4m[c=++n4m]=tsi;try{if((o4m[c]=I4m,b).c<0){d=true;return}(o4m[c]=M8m,!(o4m[c]=z5m,b).a.a)&&(o4m[c]=Y4m,(o4m[c]=Y4m,b).a.a=Tyi((o4m[c]=Hhn,b.a.b.a)));switch((o4m[c]=Z4m,b).c){case 1:hsi((o4m[c]=q7m,b).a.a,null,(p4m=true,o4m[c]=o7m,p4m));break;case 2:hsi((o4m[c]=F5m,b).a.a,b.b[0],sGd(b.b[1]));}}catch(a){a=HYc(a);n4m=(o4m[c]=T5m,c);throw IYc(a)}finally{(o4m[c]=c5m,b).c<=0&&b.b[0]!=null&&b.b[0].zm();d&&(n4m=c-1)}n4m=c-1}\nfunction ksi(a,b,c,d){var e;m4m[e=++n4m]=ksi;if(RJ((o4m[e]=tcn,c))!==RJ(d.rG())&&RJ((o4m[e]=Dan,d).Gq())!==RJ(d.rG())){r$d(2,'Project Option Unchanged','You changed the global option for '+(o4m[e]=N7m,b)+fNn+(o4m[e]=O7m,d).rG()+', however the current project is '+'still configured to use '+(o4m[e]=y9m,d).Gq()+'.\\n\\n'+'Do you want to edit the options for the current '+'project as well?',new osi((o4m[e]=P7m,a)),(p4m=true,o4m[e]=r7m,p4m));n4m=e-1;return true}else{n4m=e-1;return false}n4m=e-1}\niZc(2755,1,{},lsi);var jQb=MGd(2755);iZc(2756,1,yKn,msi);_.Gn=function nsi(a){var b;m4m[b=++n4m]=nsi;jsi((o4m[b]=$4m,this.a));n4m=b-1};var hQb=MGd(2756);iZc(2757,1,cOn,osi);_.zm=function psi(){var a;m4m[a=++n4m]=psi;a4d((p4m=(o4m[a]='6339',(o4m[a]=P7m,this.a).c.a.Ug),o4m[a]=P7m,p4m));n4m=a-1};var iQb=MGd(2757);iZc(616,1,Rio);_.xm=function wsi(){var a;m4m[a=++n4m]=wsi;tsi((o4m[a]=H4m,(new xsi((p4m=this,o4m[a]=D4m,p4m))).a));n4m=a-1};iZc(2809,1,ENn,xsi);_.zm=function ysi(){var a;m4m[a=++n4m]=ysi;tsi((o4m[a]=H4m,this.a));n4m=a-1};var kQb=MGd(2809);l4m(Il)(3);\n//# sourceURL=rstudio-3.js\n")
