$wnd.rstudio.runAsyncCallback3("function r7h(a){var b;uJm[b=++vJm]=r7h;this.a=(wJm[b]=VJm,a);vJm=b-1}\nfunction C7h(a){var b;uJm[b=++vJm]=C7h;this.a=(wJm[b]=GJm,a);vJm=b-1}\nfunction t7h(a){var b;uJm[b=++vJm]=t7h;this.a=(wJm[b]=NMm,a);vJm=b-1}\nfunction ile(a,b){var c,d;uJm[d=++vJm]=ile;for(wJm[d]=rOm,c=0;(wJm[d]=rOm,c)<(wJm[d]=WRm,a.p.a).length;wJm[d]=rOm,c++){if(rbd((wJm[d]=RRm,a).p,c).EL==b){Gme((wJm[d]=CLm,(wJm[d]=ILm,a).s),BCd((xJm=(wJm[d]=ILm,c),wJm[d]=CLm,xJm)));break}}vJm=d-1}\nfunction q7h(a,b){var c;uJm[c=++vJm]=q7h;this.c=(wJm[c]=UKm,a);this.b=(xJm=LSh((wJm[c]=tOm,a).c,Ico,Jco,(xJm=hsn,wJm[c]=f4m,xJm)),wJm[c]=tOm,xJm).mE();this.a=(xJm=LSh((wJm[c]=nKm,a).c,Kco,Lco,(xJm=Mco,wJm[c]=i4m,xJm)),wJm[c]=nKm,xJm).mE();$h((wJm[c]=VJm,b),new r7h(this),(xJm=(wJm[c]=$Jm,BA)?BA:(BA=new Wx),wJm[c]=G0m,xJm));vJm=c-1}\nfunction o7h(a){var b,c;uJm[c=++vJm]=o7h;b=p7h((wJm[c]=WJm,a),'weaving Rnw files',(wJm[c]=MPm,a).b,(xJm=LSh((wJm[c]=$Lm,a).c.c,Ico,Jco,(xJm=hsn,wJm[c]=f4m,xJm)),wJm[c]=WJm,xJm));(wJm[c]=yKm,b)||p7h((wJm[c]=KPm,a),'LaTeX typesetting',(wJm[c]=AKm,a).a,(xJm=LSh((wJm[c]=IOm,a).c.c,Kco,Lco,(xJm=Mco,wJm[c]=i4m,xJm)),wJm[c]=KPm,xJm));vJm=c-1}\nfunction m7h(a,b,c){var d,e;uJm[e=++vJm]=m7h;wJm[e]=VOm,d=X1h((wJm[e]=PWm,(wJm[e]=VOm,a).b.a));nle((wJm[e]=xKm,d),(xJm=jVh(Rig((wJm[e]=IKm,(wJm[e]=qXm,i7e(),(wJm[e]=xKm,h7e)).a))),wJm[e]=xKm,xJm));!(wJm[e]=aOm,!(wJm[e]=CKm,b))&&ile((wJm[e]=ZJm,d),b);tle((wJm[e]=XJm,d),c);kde((wJm[e]=YJm,d),(xJm=true,wJm[e]=LRm,xJm));new q7h((wJm[e]=EKm,a),d);((wJm[e]=OJm,Zcf())||!!(wJm[e]=wOm,$wnd).remoteDesktop)&&(wJm[e]=JJm,bdf());vJm=e-1}\nfunction y7h(b){var c,d;uJm[c=++vJm]=y7h;try{if((wJm[c]=SJm,b).c<0){d=true;return}(wJm[c]=KNm,!(wJm[c]=wKm,b).a.a)&&(wJm[c]=TJm,(wJm[c]=TJm,b).a.a=Ydi((wJm[c]=OWm,b.a.b.a)));switch((wJm[c]=UJm,b).c){case 1:m7h((wJm[c]=oMm,b).a.a,null,(xJm=true,wJm[c]=mMm,xJm));break;case 2:m7h((wJm[c]=CKm,b).a.a,b.b[0],iBd(b.b[1]));}}catch(a){a=PUc(a);vJm=(wJm[c]=QKm,c);throw QUc(a)}finally{(wJm[c]=$Jm,b).c<=0&&b.b[0]!=null&&b.b[0].zm();d&&(vJm=c-1)}vJm=c-1}\nfunction p7h(a,b,c,d){var e;uJm[e=++vJm]=p7h;if(XG((wJm[e]=wRm,c))!==XG(d.mE())&&XG((wJm[e]=DPm,d).bq())!==XG(d.mE())){aVd(2,'Project Option Unchanged','You changed the global option for '+(wJm[e]=LMm,b)+$pn+(wJm[e]=MMm,d).mE()+', however the current project is '+'still configured to use '+(wJm[e]=zOm,d).bq()+'.\\n\\n'+'Do you want to edit the options for the current '+'project as well?',new t7h((wJm[e]=NMm,a)),(xJm=true,wJm[e]=pMm,xJm));vJm=e-1;return true}else{vJm=e-1;return false}vJm=e-1}\nqVc(2737,1,{},q7h);var TMb=CBd(2737);qVc(2738,1,onn,r7h);_.cn=function s7h(a){var b;uJm[b=++vJm]=s7h;o7h((wJm[b]=VJm,this.a));vJm=b-1};var RMb=CBd(2738);qVc(2739,1,Xqn,t7h);_.zm=function u7h(){var a;uJm[a=++vJm]=u7h;L$d((xJm=(wJm[a]='6339',(wJm[a]=NMm,this.a).c.a.Ug),wJm[a]=NMm,xJm));vJm=a-1};var SMb=CBd(2739);qVc(616,1,zUn);_.xm=function B7h(){var a;uJm[a=++vJm]=B7h;y7h((wJm[a]=QJm,(new C7h((xJm=this,wJm[a]=GJm,xJm))).a));vJm=a-1};qVc(2791,1,xqn,C7h);_.zm=function D7h(){var a;uJm[a=++vJm]=D7h;y7h((wJm[a]=QJm,this.a));vJm=a-1};var UMb=CBd(2791);tJm(Gl)(3);\n//# sourceURL=rstudio-3.js\n")
