$wnd.rstudio.runAsyncCallback26("function VPd(){}\nfunction wfj(){}\nfunction Zfj(a){this.a=a}\nfunction pfj(a,b){jij(a.c,b)}\nfunction BPd(a){var b;yPd(a);b=0;while(a.a.gs(new VPd)){b=YUc(b,1)}return b}\nfunction Tij(a){var b,c,d;d=new Kbd;for(c=new Khe((new Ihe(_2d(a.g))).a);c.b.length>c.a;){b=c.b[c.a++];ubd(d,a.g[b])}return d}\nfunction ifj(a,b){var c,d;c=Tij(Fjj(a.d.a));if(c.a.length==0){ymj(a.b,false);b.zm()}d=BPd(CPd(new GPd(null,new WMd(c)),new wfj));if(ZUc(d,0)>0){TUc().vA(1,'Local Jobs Still Running','The Jobs tab cannot be closed while there '+(ZUc(d,1)>0?'are unfinished local jobs':'is an unfinished local job')+'.'+'\\n\\nWait until all local jobs have completed.').wA();return}ymj(a.b,false);b.zm()}\nfunction Vfj(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=Mjj(a.a.b.a);m6h(a.a,a.a.a)}switch(a.c){case 1:ifj(a.a.a,a.b[0]);break;case 2:jfj(a.a.a);break;case 3:a.a.a.H.AE();break;case 4:a.a.a.H.BE();break;case 5:kfj(a.a.a,a.b[0]);break;case 6:lfj(a.a.a,a.b[0]);break;case 7:mfj(a.a.a,a.b[0]);break;case 8:nfj(a.a.a,a.b[0]);break;case 9:ofj(a.a.a,a.b[0]);break;case 10:a.a.a.H.CE();break;case 11:a.a.a.H.DE();break;case 12:pfj(a.a.a,a.b[0]);}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nxVc(2075,1,{},VPd);_.ks=function WPd(a){};var xW=JBd(2075);xVc(6706,1,{},wfj);_.ls=function xfj(a){return a.type==1&&a.state==2};var E3b=JBd(6706);xVc(314,1,rgn);_.xm=function Yfj(){Vfj((new Zfj(this)).a)};xVc(6234,1,ASm,Zfj);_.zm=function $fj(){Vfj(this.a)};var L3b=JBd(6234);AJm(El)(26);\n//# sourceURL=rstudio-26.js\n")
