$wnd.rstudio.runAsyncCallback26("function qVd(){}\nfunction uCj(){}\nfunction XCj(a){this.a=a}\nfunction nCj(a,b){hFj(a.c,b)}\nfunction YUd(a){var b;VUd(a);b=0;while(a.a.et(new qVd)){b=bZc(b,1)}return b}\nfunction RFj(a){var b,c,d;d=new vgd;for(c=new nne((new lne(D8d(a.g))).a);c.b.length>c.a;){b=c.b[c.a++];fgd(d,a.g[b])}return d}\nfunction gCj(a,b){var c,d;c=RFj(DGj(a.d.a));if(c.a.length==0){wJj(a.b,false);b.zm()}d=YUd(ZUd(new bVd(null,new rSd(c)),new uCj));if(cZc(d,0)>0){SYc().TB(1,'Local Jobs Still Running','The Jobs tab cannot be closed while there '+(cZc(d,1)>0?'are unfinished local jobs':'is an unfinished local job')+'.'+'\\n\\nWait until all local jobs have completed.').UB();return}wJj(a.b,false);b.zm()}\nfunction TCj(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=KGj(a.a.b.a);tsi(a.a,a.a.a)}switch(a.c){case 1:gCj(a.a.a,a.b[0]);break;case 2:hCj(a.a.a);break;case 3:a.a.a.H.PG();break;case 4:a.a.a.H.QG();break;case 5:iCj(a.a.a,a.b[0]);break;case 6:jCj(a.a.a,a.b[0]);break;case 7:kCj(a.a.a,a.b[0]);break;case 8:lCj(a.a.a,a.b[0]);break;case 9:mCj(a.a.a,a.b[0]);break;case 10:a.a.a.H.RG();break;case 11:a.a.a.H.SG();break;case 12:nCj(a.a.a,a.b[0]);}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nCZc(2086,1,{},qVd);_.it=function rVd(a){};var HZ=eHd(2086);CZc(6747,1,{},uCj);_.jt=function vCj(a){return a.type==1&&a.state==2};var m7b=eHd(6747);CZc(313,1,XHn);_.xm=function WCj(){TCj((new XCj(this)).a)};CZc(6275,1,Oen,XCj);_.zm=function YCj(){TCj(this.a)};var t7b=eHd(6275);F5m(Gl)(26);\n//# sourceURL=rstudio-26.js\n")
