$wnd.rstudio.runAsyncCallback26("function IPd(){}\nfunction jej(){}\nfunction Mej(a){this.a=a}\nfunction cej(a,b){Ygj(a.c,b)}\nfunction oPd(a){var b;lPd(a);b=0;while(a.a.gs(new IPd)){b=LUc(b,1)}return b}\nfunction Ghj(a){var b,c,d;d=new xbd;for(c=new xhe((new vhe(O2d(a.g))).a);c.b.length>c.a;){b=c.b[c.a++];hbd(d,a.g[b])}return d}\nfunction Xdj(a,b){var c,d;c=Ghj(sij(a.d.a));if(c.a.length==0){llj(a.b,false);b.zm()}d=oPd(pPd(new tPd(null,new JMd(c)),new jej));if(MUc(d,0)>0){GUc().nA(1,'Local Jobs Still Running','The Jobs tab cannot be closed while there '+(MUc(d,1)>0?'are unfinished local jobs':'is an unfinished local job')+'.'+'\\n\\nWait until all local jobs have completed.').oA();return}llj(a.b,false);b.zm()}\nfunction Iej(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=zij(a.a.b.a);a5h(a.a,a.a.a)}switch(a.c){case 1:Xdj(a.a.a,a.b[0]);break;case 2:Ydj(a.a.a);break;case 3:a.a.a.G.qE();break;case 4:a.a.a.G.rE();break;case 5:Zdj(a.a.a,a.b[0]);break;case 6:$dj(a.a.a,a.b[0]);break;case 7:_dj(a.a.a,a.b[0]);break;case 8:aej(a.a.a,a.b[0]);break;case 9:bej(a.a.a,a.b[0]);break;case 10:a.a.a.G.sE();break;case 11:a.a.a.G.tE();break;case 12:cej(a.a.a,a.b[0]);}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nkVc(2070,1,{},IPd);_.ks=function JPd(a){};var xW=wBd(2070);kVc(6694,1,{},jej);_.ls=function kej(a){return a.type==1&&a.state==2};var s3b=wBd(6694);kVc(314,1,efn);_.xm=function Lej(){Iej((new Mej(this)).a)};kVc(6222,1,nRm,Mej);_.zm=function Nej(){Iej(this.a)};var z3b=wBd(6222);nIm(El)(26);\n//# sourceURL=rstudio-26.js\n")
