$wnd.rstudio.runAsyncCallback7("function vwj(a){this.a=a}\nfunction Fvj(a,b){this.a=a;this.b=b}\nfunction Bvj(a,b){b==null?x_d(a,F0n):x_d(a,b)}\nfunction Qvj(a,b){Zh(a.d,new _9d(false));Hvj(a.d,b,0)}\nfunction Emh(a,b){ooh(a,dgn,'markers_tab_closed',new tE,b)}\nfunction Cvj(a,b){var c,d,e,f,g,h,i;d=a.p;smd(d.n);for(g=b,h=0,i=g.length;h<i;++h){f=g[h];c=new Fvj(a,f);e=new EWc(CWc(new DWc,f).a.a);rVe(d,new znd(e,c))}}\nfunction Hvj(a,b,c){var d;q2f(a.b);Bvj(a.c,null);Cvj(a.c,hG(cG(GU,1),YIm,2,6,[]));if(b.markers){d=b.markers;v2f(a.b,null,d.base_path,d.markers,c,false);Cvj(a.c,uhe(b.names));Bvj(a.c,d.name)}}\nfunction Pvj(a,b){var c,d,e,f,g;g=b.a.markers_state;if(g.markers){Zh(a.d,new _9d(true));Hvj(a.d,b.a.markers_state,b.a.auto_select);e=g.markers;if(e){d=e.markers;if(d.length>0){f=null;c=b.a.auto_select;c==1?(f=d[0]):c==2&&(f=c2f(d));!!f&&yLf(a.b,(Zbe(),pce(f.path,false,-1,0)),KTd(f.line,f.column),false)}}}else{Zh(a.d,new U9d)}}\nfunction rwj(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=Ewj(a.a.b.a);a5h(a.a,a.a.a)}switch(a.c){case 1:Ovj(a.a.a);break;case 2:a.a.a.G.qE();break;case 3:a.a.a.G.rE();break;case 4:Emh(a.a.a.c,new q9e);break;case 5:Pvj(a.a.a,a.b[0]);break;case 6:a.a.a.G.sE();break;case 7:a.a.a.G.tE();break;case 8:Qvj(a.a.a,a.b[0]);}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].zm()}}\nkVc(7248,1,OKm,Fvj);_.zm=function Gvj(){_A(this.a,this.b)};var D7b=wBd(7248);kVc(419,1,efn);_.xm=function uwj(){rwj((new vwj(this)).a)};kVc(5997,1,nRm,vwj);_.zm=function wwj(){rwj(this.a)};var Q7b=wBd(5997);nIm(El)(7);\n//# sourceURL=rstudio-7.js\n")
